(***************************************************)
(* Office ToolBar Components                       *)
(* Common Routings                                 *)
(* Version 1.0                                     *)
(***************************************************)
(*                                                 *)
(* (c) 1998-99 Evgesoft                            *)
(* All right reserved.                             *)
(*                                                 *)
(***************************************************)
(* Internet: dev@evgesoft.com                      *)
(* WWW:                                            *)
(*   http://www.evgesoft.com                       *)
(***************************************************)

unit op_common;

interface

uses Classes, Graphics, Windows, AppBar;

const

// Registery section

  rsTabs         = 'Tabs';
  rsCount        = 'Count';
  rsVisible      = 'Show';
  rsBackStyle    = 'BackStyle';
  rsColor        = 'Color';
  rsBCount       = 'Buttons';
  rsButton       = 'Button';
  rsAutoRun      = 'AutoRun';
  rsShowHints    = 'ShowHints';
  rsBackFile     = 'BackFile';
  rsActiveTab    = 'ActiveTab';


// Regystry function

function ReadBool(const Section, Ident: string; Default: Boolean): Boolean;
function ReadInteger(const Section, Ident: string; Default: Longint): Longint;
function ReadString(const Section, Ident, Default: string): string;
procedure WriteBool(const Section, Ident: string; Value: Boolean);
procedure WriteInteger(const Section, Ident: string; Value: Longint);
procedure WriteString(const Section, Ident, Value: string);

procedure AngleTextOut(Canvas: TCanvas; X, Y: integer; Angle: integer;
  AText: string);

function GetFileIcon(FileName: string): TIcon;

implementation

uses Registry, ShellAPI, MMSystem;

// Read/Write to/from Regisrty

function ReadBool(const Section, Ident: string; Default: Boolean): Boolean;
var
  R: TRegINIfile;
begin
  R := TRegINIfile.Create(AB_DEF_KEY_NAME);
  Result := R.ReadBool(Section, Ident, Default);
  R.Free;
end;

function ReadInteger(const Section, Ident: string; Default: Longint): Longint;
var
  R: TRegINIfile;
begin
  R := TRegINIfile.Create(AB_DEF_KEY_NAME);
  Result := R.ReadInteger(Section, Ident, Default);
  R.Free;
end;

function ReadString(const Section, Ident, Default: string): string;
var
  R: TRegINIfile;
begin
  R := TRegINIfile.Create(AB_DEF_KEY_NAME);
  Result := R.ReadString(Section, Ident, Default);
  R.Free;
end;

procedure WriteBool(const Section, Ident: string; Value: Boolean);
var
  R: TRegINIfile;
begin
  R := TRegINIfile.Create(AB_DEF_KEY_NAME);
  R.WriteBool(Section, Ident, Value);
  R.Free;
end;

procedure WriteInteger(const Section, Ident: string; Value: Longint);
var
  R: TRegINIfile;
begin
  R := TRegINIfile.Create(AB_DEF_KEY_NAME);
  R.WriteInteger(Section, Ident, Value);
  R.Free;
end;

procedure WriteString(const Section, Ident, Value: string);
var
  R: TRegINIfile;
begin
  R := TRegINIfile.Create(AB_DEF_KEY_NAME);
  R.WriteString(Section, Ident, Value);
  R.Free;
end;

// Angle Text Out
procedure AngleTextOut(Canvas: TCanvas; X, Y: integer; Angle: integer;
  AText: string);
var
  LogRec: TLOGFONT;              { Storage area for font information }
  OldFont, NewFont: HFONT;
begin
  { Get the current font information. We only want to modify the angle }
  GetObject(Canvas.Font.Handle, SizeOf(LogRec), @LogRec);
  LogRec.lfEscapement := Angle * 10;
  LogRec.lfOrientation := Angle * 10; {see win32 api?}
  LogRec.lfOutPrecision := OUT_TT_ONLY_PRECIS;
       {The microsoft documentation claims that this forces use of
        a truetype font (the only rotatable fonts commonly available).
         -> This does not work under win95. Choose a truetype font
              for the Titlefont property instead for vertical text
         -> Works as claimed under winNT (4.0)
        You should use truetype fonts anyway for printing}
  NewFont := CreateFontIndirect(LogRec);
  OldFont := SelectObject(Canvas.Handle, NewFont); {Save old font}
  Canvas.TextOut(X, Y + (Canvas.TextWidth(AText) div 2), AText);
  NewFont := SelectObject(Canvas.Handle, OldFont); {Restore oldfont}
  DeleteObject(NewFont);
end;

function GetFileIcon(FileName: string): TIcon;
var
  Info: TSHFileInfo;
begin
  Result := TIcon.Create;
  SHGetFileInfo(PChar(FileName), 0, Info, SizeOf(Info),
    SHGFI_ICON or SHGFI_SMALLICON);
  Result.Handle := Info.hIcon;
end;

end.
